# Copyright (c) 2001 New Information Paradigms Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.
#
# $Id: User.py,v 1.2 2002/05/24 14:38:18 chrisw Exp $

from AccessControl.User import BasicUser
from cPickle import UnpickleableError
import xmlrpclib
from binascii import b2a_base64
from OGoServer import OGoServer

from zLOG import LOG


class OGoUser(BasicUser):

    # we don't want to support the domains thing
    domains = ()

    def __init__(self,cdata,dict=None):
        d = self.__dict__
        d['cdata'] = cdata
        if dict:
            d['__']      = dict['password']
            d['name']    = dict['name']
            d['roles']   = dict['roles']

        ogorpc = OGoServer(self.cdata)
        try:
            id = ogorpc().account.getLoginAccountId()
        except :
            raise 'XMLRPCError','Cannot connect OpenGroupware XMLRPC server.'

    def __setattr__(self,name,value):
        # This type of user object should never get modified
        raise AttributeError, 'This object is immutable'

    def __getstate__(self):
        """Don't let simple user objects get pickled"""
        raise UnpickleableError, "This object cannot be pickled"

    def _getPassword(self):
        """Return the password of the user."""
        return self.__

    def getDomains(self):
        """Return the list of domain restrictions for a user"""
        # This is always an empty tuple, since we don't support
        # domain restrictions.
        return ()

    def getRoles(self):
        """Return the list of roles assigned to a user.
        The OpenGroupware.org teams are converted to Zope roles."""
        # OGo teams are assigned to zope roles
        #teams  = OGoServer(self.rootpw)().account.getTeamsForLogin(self.name)
        teams  = OGoServer(self.cdata)().account.getTeamsForLogin(self.name)
        roles = []
        for item in teams:
             roles.append(item['description'])
        roles += ['Authenticated',]
        return roles

    def getUserName(self):
        """Return the username of a user"""
        return self.name

    def getOGoUserNames(self):
        """Return a list of user names."""
        #ogorpc = OGoServer(self.rootpw)
        ogorpc = OGoServer(self.cdata)
        templateUsers = ogorpc().account.getAllTemplateUserLogins()
        allUsers      = ogorpc().account.fetch(
            {
            'qualifier'	:	"login like '*'",
            }
        )
        
        namelist = []
        for account in allUsers: namelist.append(account['login'])
        for tlogin in templateUsers: namelist.remove(tlogin)
        return namelist

    def addUser(self,name,password,roles):
        return self

    def getOGoUserDetails(self,cdata,name):
        password = OGoServer(cdata)().account.passwordForLogin(name)
        pw = '{CRYPT}' + 'MW!'
        if password:
            pw = '{CRYPT}' + password
        return {
            'password': pw,
            'roles': 'OGoUser',
            }

