# Copyright (c) 2004 Martin Werthmoeller <mw@werthmoeller.de>
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.
#
# $Id: $

ManageUsersPermission = 'Manage users'

from AccessControl import ClassSecurityInfo
from AccessControl.User import BasicUserFolder
from Globals import InitializeClass, HTMLFile
from Shared.DC.ZRDB.Results import Results

from OGoUser import OGoUser
from OGoServer import OGoServer


# add OGoUserFolder to container
addOGoUserFolderForm = HTMLFile('dtml/addUserFolder',globals())
def addOGoUserFolder(self,ogorootpw,ogohost,ogoport,REQUEST=None):
    """Add a OGoUserFolder to a container as acl_users"""
    if not ogoport: ogoport = 20001
    port=int(ogoport)
    ob=OGoUserFolder(ogorootpw,ogohost,port)
    self._setObject('acl_users', ob)
    if REQUEST is not None:
        return self.manage_main(self,REQUEST)


class OGoUserFolder(BasicUserFolder):

    meta_type="OpenGroupware User Folder"

    security = ClassSecurityInfo()

    manage_options=(
        BasicUserFolder.manage_options[0:1]
        + BasicUserFolder.manage_options[2:]
        )

    manage_main = HTMLFile("dtml/manage_main", globals())

    getOGoUserDetails = OGoUser.getOGoUserDetails
    getOGoUserNames   = OGoUser.getOGoUserNames

    def __init__(self,ogorootpw,ogohost,ogoport):
        self.cdata = {
            'rootpw': ogorootpw,
            'host':   ogohost,
            'port':   ogoport,
            }
        ogo = OGoUser(self.cdata)

    security.declareProtected(ManageUsersPermission,'getUserNames')
    def getUserNames(self):
        """Return a list of usernames"""
        getOGoUserNames = getattr(self,'getOGoUserNames',None)
        names = getOGoUserNames()
        return names


    security.declareProtected(ManageUsersPermission,'getUser')
    def getUser(self,name):
        """Return the named user object or None"""
        getOGoUserDetails = getattr(self,'getOGoUserDetails',None)
        try:
            dict = getOGoUserDetails(self.cdata,name)
            if isinstance(dict,Results):
                # extract roles from the multiple rows returned
                rows = dict
                row = rows[0]
                dict = {
                    'name':row.NAME,
                    'password':row.PASSWORD
                    }
                roles = []
                for row in rows:
                    role = row.ROLE
                    if role:
                        roles.append(role)
                dict['roles']=roles
            dict['name']=name
        except:
            dict = {
                'name':'',
                'password':'',
                'roles':''
                }
        return OGoUser(self.cdata,dict)


    security.declareProtected(ManageUsersPermission,'getUser')
    def getUsers(self):
        """Return a list of user objects"""
        return map(self.getUser,self.getUserNames())
        

InitializeClass(OGoUserFolder)



class UnconfiguredException (Exception):
    """Exception raised when a OGoUserFolder needs configuration"""
    pass
